@@ -1,9 +1,9 @@
 package Poet::App::Command::script;
 BEGIN {
-  $Poet::App::Command::script::VERSION = '0.03';
+  $Poet::App::Command::script::VERSION = '0.04';
 }
 use File::Spec::Functions qw(rel2abs);
-use Poet::Util qw(write_file);
+use Poet::Tools qw(write_file);
 use Poet::Moose;
 use Poet::Types;
 
@@ -39,24 +39,3 @@ use warnings;
 }
 
 1;
-
-__END__
-=pod
-
-=head1 SEE ALSO
-
-L<Poet|Poet>
-
-=head1 AUTHOR
-
-Jonathan Swartz <swartz@pobox.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Jonathan Swartz.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
