@@ -1,13 +1,13 @@
 package Poet::Environment;
 BEGIN {
-  $Poet::Environment::VERSION = '0.03';
+  $Poet::Environment::VERSION = '0.04';
 }
 use Carp;
 use File::Basename;
 use File::Path;
 use File::Slurp;
 use Poet::Moose;
-use Poet::Util qw(can_load catdir);
+use Poet::Tools qw(can_load catdir);
 
 has 'app_name'    => ( required => 1 );
 has 'conf'        => ();
