@@ -1,21 +1,15 @@
 package Poet::t::Environment;
 BEGIN {
-  $Poet::t::Environment::VERSION = '0.03';
+  $Poet::t::Environment::VERSION = '0.04';
 }
-use File::Slurp;
+use Test::Class::Most parent => 'Poet::Test::Class';
 use Poet::Environment::Generator;
-use Poet::Test::Util;
-use Test::Most;
-use YAML::XS;
-use strict;
-use warnings;
-use base qw(Test::Class);
 
 sub test_environment : Tests {
     my $self = shift;
 
     my $app_name = 'TheTestApp';
-    my $env      = temp_env( app_name => $app_name );
+    my $env      = $self->temp_env( app_name => $app_name );
     my $root_dir = $env->root_dir;
 
     foreach my $subdir (qw(bin conf lib)) {
@@ -31,24 +25,3 @@ sub test_environment : Tests {
 }
 
 1;
-
-__END__
-=pod
-
-=head1 SEE ALSO
-
-L<Poet|Poet>
-
-=head1 AUTHOR
-
-Jonathan Swartz <swartz@pobox.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Jonathan Swartz.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
